﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace rosskyru
{
    public partial class FormForTray : Form
    {
        /// <summary>
        /// конструктор формы
        /// </summary>
        public FormForTray()
        {
            InitializeComponent();
            //задаем всплывающий текст-подсказку (появляется при наведении указателя на иконку в трее)
            _notifyIcon.Text = "Текст-подсказка";
            //устанавливаем значок, отображаемый в трее:
            _notifyIcon.Icon = _myIcon;
            //подписываемся на событие клика мышкой по значку в трее
            _notifyIcon.MouseClick += new MouseEventHandler(_notifyIcon_MouseClick);
            //подписываемся на событие изменения размера формы
            this.Resize += new EventHandler(FormForTray_Resize);

            //подписываемся на событие тика таймера
            _timer.Tick += new EventHandler(_timer_Tick);
        }

        /// <summary>
        /// флаг для организации мигания
        /// </summary>
        private bool _forBlinking = false;
        /// <summary>
        /// обрабатываем тик
        /// </summary>
        void _timer_Tick(object sender, EventArgs e)
        {
            //по флагу определяем, какой значок следует сейчас поставить
            if (_forBlinking)
            {
                _notifyIcon.Icon = _myEmptyIcon;
                _forBlinking = false;
            }
            else
            {
                _notifyIcon.Icon = _myIcon;
                _forBlinking = true;
            }
        }

        /// <summary>
        /// наша иконка
        /// </summary>
        private Icon _myIcon = new Icon("favicon.ico");
        /// <summary>
        /// "пустая" иконка
        /// </summary>
        private Icon _myEmptyIcon = new Icon("emptyicon.ico");

        /// <summary>
        /// здесь хранится состояние окна до сворачивания (максимизированное или нормальное)
        /// </summary>
        private FormWindowState _OldFormState;

        /// <summary>
        /// обрабатываем событие клика мышью по значку в трее
        /// </summary>
        void _notifyIcon_MouseClick(object sender, MouseEventArgs e)
        {
            //проверяем, какой кнопкой было произведено нажатие
            if (e.Button == MouseButtons.Left)//если левой кнопкой мыши
            {
                //проверяем текущее состояние окна
                if (WindowState == FormWindowState.Normal || WindowState == FormWindowState.Maximized)//если оно развернуто
                {
                    //сохраняем текущее состояние
                    _OldFormState = WindowState;
                    //сворачиваем окно
                    WindowState = FormWindowState.Minimized;
                    //скрываться в трей оно будет по событию Resize (изменение размера), которое сгенерировалось после минимизации строчкой выше               
                }
                else//в противном случае
                {
                    //и показываем на нанели задач
                    Show();
                    //разворачиваем (возвращаем старое состояние "до сворачивания")
                    WindowState = _OldFormState;
                }
            }
        }

        /// <summary>
        /// обрабатываем событие изменения размера
        /// </summary>
        void FormForTray_Resize(object sender, EventArgs e)
        {
            if (FormWindowState.Minimized == WindowState)//если окно "свернуто"
            {
                //то скрываем его
                Hide();
            }
        }
    }
}
